@@ -1,43 +1,82 @@
 #' Variance propagation for density surface models
 #'
-#' Calculate the uncertainty in predictions from a fitted DSM, including uncertainty from the detection function.
+#' Calculate the uncertainty in predictions from a fitted DSM, including
+#' uncertainty from the detection function.
 #'
-#' When we make predictions from a spatial model, we also want to know the uncertainty about that abundance estimate. Since density surface models are 2 (or more) stage models, we need to incorporate the uncertainty from the earlier stages (i.e. the detection function) into our "final" uncertainty estimate.
+#' When we make predictions from a spatial model, we also want to know the
+#' uncertainty about that abundance estimate. Since density surface models are
+#' 2 (or more) stage models, we need to incorporate the uncertainty from the
+#' earlier stages (i.e. the detection function) into our "final" uncertainty
+#' estimate.
 #'
-#' This function will refit the spatial model but include the Hessian of the offset as an extra term. Variance estimates using this new model can then be used to calculate the variance of predicted abundance estimates which incorporate detection function uncertainty. Importantly this requires that if the detection function has covariates, then these do not vary within a segment (so, for example covariates like sex cannot be used).
+#' This function will refit the spatial model but include the Hessian of the
+#' offset as an extra term. Variance estimates using this new model can then be
+#' used to calculate the variance of predicted abundance estimates which
+#' incorporate detection function uncertainty. Importantly this requires that
+#' if the detection function has covariates, then these do not vary within a
+#' segment (so, for example covariates like sex cannot be used).
 #'
-#' For more information on how to construct the prediction grid \code{data.frame}, \code{newdata}, see \code{\link{predict.dsm}}.
+#' For more information on how to construct the prediction grid `data.frame`,
+#' `newdata`, see [`predict.dsm`][predict.dsm].
 #'
-#' This routine is only useful if a detection function with covariates has been used in the DSM.
+#' This routine is only useful if a detection function with covariates has been
+#' used in the DSM.
 #'
-#' Note that we can use \code{var_type="Vc"} here (see \code{\link{gamObject}}), which is the variance-covariance matrix for the spatial model, corrected for smoothing parameter uncertainty. See Wood, Pya & S{\"a}fken (2016) for more information.
+#' Note that we can use `var_type="Vc"` here (see `gamObject`), which is the
+#' variance-covariance matrix for the spatial model, corrected for smoothing
+#' parameter uncertainty. See Wood, Pya & S{\"a}fken (2016) for more
+#' information.
 #'
-#' Models with fixed scale parameters (e.g., negative binomial) do not require an extra round of optimisation.
+#' Models with fixed scale parameters (e.g., negative binomial) do not require
+#' an extra round of optimisation.
 #'
 #' @section Diagnostics:
-#' The summary output from the function includes a simply diagnostic that shows the average probability of detection from the "original" fitted model (the model supplied to this function; column \code{Fitted.model}) and the probability of detection from the refitted model (used for variance propagation; column \code{Refitted.model}) along with the standard error of the probability of detection from the fitted model (\code{Fitted.model.se}), at the unique values of any factor covariates used in the detection function (for continuous covariates the 5%, 50% and 95% quantiles are shown). If there are large differences between the probabilities of detection then there are potentially problems with the fitted model, the variance propagation or both. This can be because the fitted model does not account for enough of the variability in the data and in refitting the variance model accounts for this in the random effect.
+#' The summary output from the function includes a simply diagnostic that shows
+#' the average probability of detection from the "original" fitted model (the
+#' model supplied to this function; column `Fitted.model`) and the probability
+#' of detection from the refitted model (used for variance propagation; column
+#' `Refitted.model`) along with the standard error of the probability of
+#' detection from the fitted model (`Fitted.model.se`), at the unique values of
+#' any factor covariates used in the detection function (for continuous
+#' covariates the 5%, 50% and 95% quantiles are shown). If there are large
+#' differences between the probabilities of detection then there are
+#' potentially problems with the fitted model, the variance propagation or
+#' both. This can be because the fitted model does not account for enough of
+#' the variability in the data and in refitting the variance model accounts for
+#' this in the random effect.
 #'
 #'
-#' @return a list with elements
-#' \tabular{ll}{\code{old_model} \tab fitted model supplied to the function as \code{model}\cr
-#'              \code{refit} \tab refitted model object, with extra term\cr
-#'              \code{pred} \tab point estimates of predictions at \code{newdata}\cr
-#'              \code{var} \tab total variance calculated over all of \code{newdata}\cr
-#'              \code{ses} \tab standard error for each prediction cell in \code{newdata}\cr
-#'  }
-#' if \code{newdata=NULL} then the last three entries are \code{NA}.
-#' @author David L. Miller, based on code from Mark V. Bravington and Sharon L. Hedley.
+#' @return a `list` with elements:
+#'  * `old_model` fitted model supplied to the function as `model`
+#'  * `refit` refitted model object, with extra term
+#'  * `pred` point estimates of predictions at `newdata`
+#'  * `var` total variance calculated over all of `newdata`
+#'  * `ses` standard error for each prediction cell in `newdata`
+#' if `newdata=NULL` then the last three entries are `NA`.
+#' @author David L. Miller, based on code from Mark V. Bravington and Sharon L.
+#' Hedley.
 #' @references
-#' Bravington, M. V., Miller, D. L., & Hedley, S. L. (2021). Variance Propagation for Density Surface Models. Journal of Agricultural, Biological and Environmental Statistics. https://doi.org/10.1007/s13253-021-00438-2
+#' Bravington, M. V., Miller, D. L., & Hedley, S. L. (2021). Variance
+#' Propagation for Density Surface Models. Journal of Agricultural, Biological
+#' and Environmental Statistics. https://doi.org/10.1007/s13253-021-00438-2
 #'
-#' Williams, R., Hedley, S.L., Branch, T.A., Bravington, M.V., Zerbini, A.N. and Findlay, K.P. (2011). Chilean Blue Whales as a Case Study to Illustrate Methods to Estimate Abundance and Evaluate Conservation Status of Rare Species. Conservation Biology 25(3), 526-535.
+#' Williams, R., Hedley, S.L., Branch, T.A., Bravington, M.V., Zerbini, A.N.
+#' and Findlay, K.P. (2011). Chilean Blue Whales as a Case Study to Illustrate
+#' Methods to Estimate Abundance and Evaluate Conservation Status of Rare
+#' Species. Conservation Biology 25(3), 526-535.
 #'
-#' Wood, S.N., Pya, N. and S{\"a}fken, B. (2016) Smoothing parameter and model selection for general smooth models. Journal of the American Statistical Association, 1-45.
+#' Wood, S.N., Pya, N. and S{\"a}fken, B. (2016) Smoothing parameter and model
+#' selection for general smooth models. Journal of the American Statistical
+#' Association, 1-45.
 #'
 #' @param model a fitted \code{\link{dsm}}.
-#' @param newdata the prediction grid. Set to \code{NULL} to avoid making predictions and just return model objects.
+#' @param newdata the prediction grid. Set to `NULL` to avoid making
+#' predictions and just return model objects.
 #' @param trace for debugging, see how the scale parameter estimation is going.
-#' @param var_type which variance-covariance matrix should be used (\code{"Vp"} for variance-covariance conditional on smoothing parameter(s), \code{"Vc"} for unconditional). See \code{\link{gamObject}} for an details/explanation. If in doubt, stick with the default, \code{"Vp"}.
+#' @param var_type which variance-covariance matrix should be used (`"Vp"` for
+#' variance-covariance conditional on smoothing parameter(s), `"Vc"` for
+#' unconditional). See [`gamObject`][gamObject] for an details/explanation. If
+#' in doubt, stick with the default, `"Vp"`.
 #' @export
 #' @importFrom utils relist
 #'
@@ -50,7 +89,7 @@
 # data(mexdolphins)
 #
 # # fit a detection function
-# df <- ds(distdata, max(distdata$distance),
+# df <- ds(distdata, truncation=6000,
 #          key = "hn", adjustment = NULL)
 #
 # # fit a simple smooth of x and y
@@ -239,19 +278,9 @@ dsm_varprop <- function(model, newdata=NULL, trace=FALSE, var_type="Vp"){
     if("fake_ddf" %in% class(this_ddf)){
       next
     }
-#    opt_details <- attr(this_ddf$ds, "details")
-#    if(is.matrix(opt_details)){
-#      this_hess <- opt_details[nrow(opt_details), ]$nhatend
-#    }else{
-#      this_hess <- opt_details$nhatend
-#    }
-#    if(any(is.na(this_hess))){
-#      # fall back to DS use if things are bad
-#      this_hess <- this_ddf$hessian
-#    }
 
+    # extract the hessian
     this_hess <- get_hessian(this_ddf)
-
     # drop that matrix into the big hessian
     hess[ii:(ii+nrow(this_hess)-1), ii:(ii+ncol(this_hess)-1)] <- this_hess
 
@@ -305,11 +334,6 @@ dsm_varprop <- function(model, newdata=NULL, trace=FALSE, var_type="Vp"){
   # make a sandwich
   var_p <- dNdbeta %*% vc %*% t(dNdbeta)
 
-  # apply the link function to the offset
-  # NB this is because refit is a gam not dsm object! If refit is dsm
-  #    then this will get done in predict.dsm
-  newdata$off.set <- linkfn(newdata$off.set)
-
   # if we are using Vc we need to set unconditional=TRUE
   if(var_type=="Vc"){
     uncond <- TRUE
