@@ -1,11 +1,9 @@
-library(dsm)
-library(Distance)
-library(testthat)
-
 lnl.tol<-1e-4
 par.tol<-1e-6
 
 context("prediction")
+library(Distance)
+
 
 # load the Gulf of Mexico dolphin data
 data(mexdolphins)
